@@ -305,6 +305,21 @@ class Metadata:
             raise st.DeserializationError("Some input bytes were not read")
         return v
 
+    def decode_structure(self) -> typing.Union[None, "GeneralMetadataV0", "TravelRuleMetadataV0", "RefundMetadataV0"]:
+        """decode metadata structure
+
+        Returns None for a non-structure type or undefined
+        """
+
+        type_index = type(self).INDEX
+        if type_index == 1:
+            return typing.cast(GeneralMetadataV0, self.value.value)
+        elif type_index == 2:
+            return typing.cast(TravelRuleMetadataV0, self.value.value)
+        elif type_index == 4:
+            return typing.cast(RefundMetadataV0, self.value.value)
+        return None
+
 
 @dataclass(frozen=True)
 class Metadata__Undefined(Metadata):
@@ -646,7 +661,7 @@ class TransactionArgument__U8Vector(TransactionArgument):
 @dataclass(frozen=True)
 class TransactionArgument__Bool(TransactionArgument):
     INDEX = 5  # type: int
-    value: st.bool
+    value: bool
 
 
 TransactionArgument.VARIANTS = [
